==> ejc-jltest-impl-3.0.0-20240319.021724-76-sources.jar: com/ejianc/business/jltest/margin/bean/RiskPayConfirmationEntity.java <==
package com.ejianc.business.jltest.margin.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 风险金缴纳确认
 * 
 * @author generator
 * 
 */
 @TableName("ejc_jltest_risk_payment_confirmation")
public class RiskPayConfirmationEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="employee_detail_id")
    private Long employeeDetailId; // 员工明细主键
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="org_code")
    private String orgCode; // 组织code
    @TableField(value="payable_amount")
    private BigDecimal payableAmount; // 应缴纳金额
    @TableField(value="current_payment_amount")
    private BigDecimal currentPaymentAmount; // 本期缴纳金额
    @TableField(value="payment_amount_total")
    private BigDecimal paymentAmountTotal; // 含本期已缴纳金额
    @TableField(value="proportion")
    private String proportion; // 含本期已缴纳比例
    @TableField(value="remaining_payment_amount")
    private BigDecimal remainingPaymentAmount; // 剩余缴纳金额
    @TableField(value="is_staged")
    private Integer isStaged; // 是否分期
    @TableField(value="payment_date")
    private Date paymentDate; // 缴纳日期
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="department_id")
    private Long departmentId; // 经办部门
    @TableField(value="department_name")
    private String departmentName; // 经办部门名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="apply_for_time")
    private Date applyForTime; // 申请时间
    @TableField(value="apply_people_name")
    private String applyPeopleName; // 申请人姓名
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="confirmation_state")
    private Integer confirmationState; // 确认状态(-1：待确认 0：确认中    1：已确认 )
    
    
    

    public Long getEmployeeDetailId() {
        return employeeDetailId;
    }

    public void setEmployeeDetailId(Long employeeDetailId) {
        this.employeeDetailId = employeeDetailId;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public BigDecimal getPayableAmount() {
        return payableAmount;
    }

    public void setPayableAmount(BigDecimal payableAmount) {
        this.payableAmount = payableAmount;
    }
    public BigDecimal getCurrentPaymentAmount() {
        return currentPaymentAmount;
    }

    public void setCurrentPaymentAmount(BigDecimal currentPaymentAmount) {
        this.currentPaymentAmount = currentPaymentAmount;
    }
    public BigDecimal getPaymentAmountTotal() {
        return paymentAmountTotal;
    }

    public void setPaymentAmountTotal(BigDecimal paymentAmountTotal) {
        this.paymentAmountTotal = paymentAmountTotal;
    }
    public String getProportion() {
        return proportion;
    }

    public void setProportion(String proportion) {
        this.proportion = proportion;
    }
    public BigDecimal getRemainingPaymentAmount() {
        return remainingPaymentAmount;
    }

    public void setRemainingPaymentAmount(BigDecimal remainingPaymentAmount) {
        this.remainingPaymentAmount = remainingPaymentAmount;
    }
    public Integer getIsStaged() {
        return isStaged;
    }

    public void setIsStaged(Integer isStaged) {
        this.isStaged = isStaged;
    }
    public Date getPaymentDate() {
        return paymentDate;
    }

    public void setPaymentDate(Date paymentDate) {
        this.paymentDate = paymentDate;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Date getApplyForTime() {
        return applyForTime;
    }

    public void setApplyForTime(Date applyForTime) {
        this.applyForTime = applyForTime;
    }
    public String getApplyPeopleName() {
        return applyPeopleName;
    }

    public void setApplyPeopleName(String applyPeopleName) {
        this.applyPeopleName = applyPeopleName;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getConfirmationState() {
        return confirmationState;
    }

    public void setConfirmationState(Integer confirmationState) {
        this.confirmationState = confirmationState;
    }
    
}

==> ejc-jltest-impl-3.0.0-20240323.031742-97-sources.jar: com/ejianc/business/jltest/margin/bean/RiskPayConfirmationEntity.java <==
package com.ejianc.business.jltest.margin.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 风险金缴纳确认
 * 
 * @author generator
 * 
 */
 @TableName("ejc_jltest_risk_payment_confirmation")
public class RiskPayConfirmationEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="employee_detail_id")
    private Long employeeDetailId; // 员工明细主键
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="org_code")
    private String orgCode; // 组织code
    @TableField(value="payable_amount")
    private BigDecimal payableAmount; // 应缴纳金额
    @TableField(value="current_payment_amount")
    private BigDecimal currentPaymentAmount; // 本期缴纳金额
    @TableField(value="payment_amount_total")
    private BigDecimal paymentAmountTotal; // 含本期已缴纳金额
    @TableField(value="proportion")
    private BigDecimal proportion; // 含本期已缴纳比例
    @TableField(value="remaining_payment_amount")
    private BigDecimal remainingPaymentAmount; // 剩余缴纳金额
    @TableField(value="is_staged")
    private Integer isStaged; // 是否分期
    @TableField(value="payment_date")
    private Date paymentDate; // 缴纳日期
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="department_id")
    private Long departmentId; // 经办部门
    @TableField(value="department_name")
    private String departmentName; // 经办部门名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="apply_for_time")
    private Date applyForTime; // 申请时间
    @TableField(value="apply_people_name")
    private String applyPeopleName; // 申请人姓名
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="confirmation_state")
    private Integer confirmationState; // 确认状态(-1：待确认 0：确认中    1：已确认 )
    @TableField(value="isOk")
    private Integer isok;//是否已确认  0 未确认 1 已确认

    @TableField(value="submitter")
    private String submitter;//提交人

    @TableField(value="confirm_time")
    private  Date confirmTime;//确认时间
    @TableField(value="confirm_person")
    private String confirmPerson;//确认人

    public String getConfirmPerson() {
        return confirmPerson;
    }

    public void setConfirmPerson(String confirmPerson) {
        this.confirmPerson = confirmPerson;
    }

    public Date getConfirmTime() {
        return confirmTime;
    }

    public void setConfirmTime(Date confirmTime) {
        this.confirmTime = confirmTime;
    }

    public String getSubmitter() {
        return submitter;
    }

    public void setSubmitter(String submitter) {
        this.submitter = submitter;
    }

    public Integer getIsok() {
        return isok;
    }

    public void setIsok(Integer isok) {
        this.isok = isok;
    }

    public Long getEmployeeDetailId() {
        return employeeDetailId;
    }

    public void setEmployeeDetailId(Long employeeDetailId) {
        this.employeeDetailId = employeeDetailId;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public BigDecimal getPayableAmount() {
        return payableAmount;
    }

    public void setPayableAmount(BigDecimal payableAmount) {
        this.payableAmount = payableAmount;
    }
    public BigDecimal getCurrentPaymentAmount() {
        return currentPaymentAmount;
    }

    public void setCurrentPaymentAmount(BigDecimal currentPaymentAmount) {
        this.currentPaymentAmount = currentPaymentAmount;
    }
    public BigDecimal getPaymentAmountTotal() {
        return paymentAmountTotal;
    }

    public void setPaymentAmountTotal(BigDecimal paymentAmountTotal) {
        this.paymentAmountTotal = paymentAmountTotal;
    }

    public BigDecimal getProportion() {
        return proportion;
    }

    public void setProportion(BigDecimal proportion) {
        this.proportion = proportion;
    }

    public BigDecimal getRemainingPaymentAmount() {
        return remainingPaymentAmount;
    }

    public void setRemainingPaymentAmount(BigDecimal remainingPaymentAmount) {
        this.remainingPaymentAmount = remainingPaymentAmount;
    }
    public Integer getIsStaged() {
        return isStaged;
    }

    public void setIsStaged(Integer isStaged) {
        this.isStaged = isStaged;
    }
    public Date getPaymentDate() {
        return paymentDate;
    }

    public void setPaymentDate(Date paymentDate) {
        this.paymentDate = paymentDate;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Date getApplyForTime() {
        return applyForTime;
    }

    public void setApplyForTime(Date applyForTime) {
        this.applyForTime = applyForTime;
    }
    public String getApplyPeopleName() {
        return applyPeopleName;
    }

    public void setApplyPeopleName(String applyPeopleName) {
        this.applyPeopleName = applyPeopleName;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getConfirmationState() {
        return confirmationState;
    }

    public void setConfirmationState(Integer confirmationState) {
        this.confirmationState = confirmationState;
    }
    
}
